@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -13,7 +13,7 @@
 #ifndef __ABOUT_DIALOG_H
 #define __ABOUT_DIALOG_H
 
-#include <qdialog.h>
+#include <QDialog>
 
 class QLabel;
 class QPixmap;
