@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -11,7 +11,8 @@
  */
 
 #include "bookmark.h"
-#include <qfileinfo.h>
+#include <QFileInfo>
+#include <QAction>
 
 using namespace QComicBook;
 
@@ -19,7 +20,7 @@ Bookmark::Bookmark()
 {
 }
 
-Bookmark::Bookmark(const QString &cbname, int cbpage): name(cbname), page(cbpage), id(0)
+Bookmark::Bookmark(const QString &cbname, int cbpage): name(cbname), page(cbpage), id(NULL)
 {
 }
 
@@ -37,7 +38,7 @@ int Bookmark::getPage() const
 	return page; 
 }
 
-int Bookmark::getId() const
+QAction* Bookmark::getId() const
 {
 	return id; 
 }
@@ -52,7 +53,7 @@ void Bookmark::setPage(int cbpage)
 	page = cbpage;
 }
 
-void Bookmark::setId(int n)
+void Bookmark::setId(QAction *n)
 {
 	id = n;
 }
