@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -17,6 +17,8 @@
 
 #include <qstring.h>
 
+class QAction;
+
 namespace QComicBook
 {
 	class Bookmark
@@ -24,7 +26,7 @@ namespace QComicBook
 		private:
 			QString name; //!<comic book full path
 			int page; //!<page number
-			int id; //!<item identifier in popup menu
+			QAction *id; //!<item identifier in popup menu
 
 		public:
 			Bookmark();
@@ -32,10 +34,10 @@ namespace QComicBook
 			~Bookmark();
 			const QString& getName() const;
 			int getPage() const;
-			int getId() const;
+			QAction* getId() const;
 			void setName(const QString &cbname);
 			void setPage(int cbpage);
-			void setId(int n);
+			void setId(QAction *n);
 			bool isValid();
 			QString menuItemName();
 	};
