@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -15,36 +15,36 @@
 #ifndef __BOOKMARKS_H
 #define __BOOKMARKS_H
 
-#include <qstring.h>
-#include <qvaluelist.h>
-#include <qptrlist.h>
-#include <qmap.h>
+#include <QString>
+#include <QList>
+#include <QMap>
+#include <QAction>
 #include "bookmark.h"
 
-class QPopupMenu;
+class QMenu;
 
 namespace QComicBook
 {
 	class Bookmarks
 	{
 		private:
-			QPtrList<Bookmark> blist; //!<pointers to bookmark objects
-			QMap<int, Bookmark *> bmap; //!<for fast id->bookmark lookup
-			QPopupMenu *bmenu; //!<popup menu containing bookmarks
+			QList<Bookmark *> blist; //!<pointers to bookmark objects
+			QMap<QAction *, Bookmark *> bmap; //!<for fast action->bookmark lookup
+			QMenu *bmenu; //!<popup menu containing bookmarks
 			bool changed; //!<flag indicator to decide if bookmarks should be saved
 			QString fname; //!<bookmarks file
 
 		public:
-			Bookmarks(QPopupMenu *menu);
+			Bookmarks(QMenu *menu);
 			~Bookmarks();
 			bool load();
 			bool save();
 
 			void set(const QString &cbname, int page);
 			bool remove(const QString &cbname);
-			bool remove(int id);
-			bool get(int id, Bookmark &b);
-			QValueList<Bookmark> get();
+			bool remove(QAction *action);
+			bool get(QAction *action, Bookmark &b);
+			QList<Bookmark> get() const;
 			bool exists(const QString &cbname);
 	};
 }
