@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -16,8 +16,9 @@
 #include "imgview.h"
 #include "history.h"
 #include "enummap.h"
-#include <qobject.h>
-#include <qfont.h>
+#include <QObject>
+#include <QFont>
+#include <QByteArray>
 
 class QSettings;
 class QRect;
@@ -46,12 +47,12 @@ namespace QComicBook
 			bool fscrhidetoolbar;
 			Size pagesize;
 			//Scaling scaling;
-			int x, y, w, h;
 			QString lastdir;
 			QColor bgcolor;
 			History recent;
 			int cachesize;
 			int thumbsage;
+			bool cacheadjust;
 			bool cachethumbs;
 			bool autoinfo;
 			bool confirmexit;
@@ -60,7 +61,8 @@ namespace QComicBook
 			bool intbrowser;
 			bool showsplash;
 			QString extbrowser;
-			QString docklayout;
+			QByteArray docklayout;
+			QByteArray geometry;
 			QString tmpdir;
 			QFont font;
 
@@ -89,13 +91,13 @@ namespace QComicBook
 			bool japaneseMode() const;
 			bool continuousScrolling() const;
 			bool scrollbarsVisible() const;
-			QRect geometry() const;
 			Size pageSize() const;
 			//Scaling pageScaling() const;
 			QString lastDir() const;
 			const History& recentlyOpened() const;
 			QColor background() const;
 			int cacheSize() const;
+			bool cacheAutoAdjust() const;
 			bool cacheThumbnails() const;
 			int thumbnailsAge() const;
 			bool preloadPages() const;
@@ -108,6 +110,7 @@ namespace QComicBook
 			bool useInternalBrowser() const;
 			const QFont& infoFont() const;
 			QString externalBrowser() const;
+			void restoreGeometry(QMainWindow *w) const;
 			void restoreDockLayout(QMainWindow *w);
 			bool editSupport() const;
 			bool showSplash() const;
@@ -119,13 +122,13 @@ namespace QComicBook
 			void japaneseMode(bool f);
 			void continuousScrolling(bool f);
 			void scrollbarsVisible(bool f);
-			void geometry(const QRect g);
 			void pageSize(Size s);
 			//void pageScaling(Scaling s);
 			void lastDir(const QString &d);
 			void recentlyOpened(const History &hist);
 			void background(const QColor &color);
 			void cacheSize(int s);
+			void cacheAutoAdjust(bool f);
 			void cacheThumbnails(bool f);
 			void thumbnailsAge(int n);
 			void preloadPages(bool f);
@@ -139,6 +142,7 @@ namespace QComicBook
 			void infoFont(const QFont &f);
 			void externalBrowser(const QString &cmd);
 			void saveDockLayout(QMainWindow *w);
+			void saveGeometry(QMainWindow *w);
 			void editSupport(bool f);
 			void showSplash(bool f);
 			void tmpDir(const QString &dir);
