@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -30,10 +30,11 @@ History::~History()
 
 void History::append(const QString &txt)
 {
-	QStringList::iterator it = hlist.find(txt);
+	const int i = hlist.indexOf(txt);
+	
 	//
 	// text not found on the list - append it
-	if (it == hlist.end())
+	if (i < 0)
 	{
 		hlist.push_front(txt);
 		//
@@ -43,14 +44,16 @@ void History::append(const QString &txt)
 	}
 	else //put the item to the front
 	{
-		hlist.remove(it);
+		hlist.removeAt(i);
 		hlist.push_front(txt);
 	}
 }
 
 void History::remove(const QString &txt)
 {
-	hlist.remove(txt);
+	const int i = hlist.indexOf(txt);
+	if (i >= 0)
+		hlist.removeAt(i);
 }
 
 void History::set(const QStringList &l)
