@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -11,27 +11,28 @@
  */
 
 #include "icons.h"
-#include <qdir.h>
+#include <QDir>
 
 using namespace QComicBook;
 
 QString Icons::iconpath = QString::null;
-QDict<QIconSet> Icons::set;
+QHash<QString, QIcon*> Icons::set;
 
 bool Icons::init(const QString& path)
 {
 	QDir dir(iconpath = path);
-	set.setAutoDelete(true); //icons in the set will be deleted on set deletion
+	//set.setAutoDelete(true); //icons in the set will be deleted on set deletion TODO
 	return dir.exists();
 }
 
-const QIconSet& Icons::get(const QString &name)
+const QIcon& Icons::get(const QString &name)
 {
-	QIconSet *icon = set.find(name);
-	if (icon)
-		return *icon;
+	QHash<QString, QIcon *>::iterator it = set.find(name);
+	if (it != set.end())
+		return **it;
+	QIcon *icon;
 	QPixmap pixmap(iconpath + "/" + name);
-	set.insert(name, icon = new QIconSet(pixmap));
+	set.insert(name, icon = new QIcon(pixmap));
 	return *icon;
 }
 
