@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -14,7 +14,7 @@
 
 using namespace QComicBook;
 
-IconViewThumbnail::IconViewThumbnail(QIconView *view, int page, const QPixmap &pixmap): QIconViewItem(view, QString::number(page+1), pixmap), ThumbnailItem(page)
+IconViewThumbnail::IconViewThumbnail(QListWidget *view, int page, const QPixmap &pixmap): QListWidgetItem(pixmap, QString::number(page+1), view), ThumbnailItem(page)
 {
 }
 
