@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -15,15 +15,15 @@
 
 /*! \file iconviewthumbnail.h */
 
-#include <qiconview.h>
+#include <QListWidgetItem>
 #include "thumbnailitem.h"
 
 namespace QComicBook
 {
-	class IconViewThumbnail: public QIconViewItem, public ThumbnailItem
+	class IconViewThumbnail: public QListWidgetItem, public ThumbnailItem
 	{
 		public:
-			IconViewThumbnail(QIconView *view, int page, const QPixmap &pixmap);
+			IconViewThumbnail(QListWidget *view, int page, const QPixmap &pixmap);
 			virtual ~IconViewThumbnail();
 	};
 }
