@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -16,7 +16,8 @@
 /*! \file imgarchiver.h */
 
 #include "imgarchivesink.h"
-#include <qvaluelist.h>
+#include <QList>
+#include <QProcess>
 
 namespace QComicBook
 {
@@ -39,14 +40,14 @@ namespace QComicBook
 			virtual void doCleanup();
 
 		protected slots:
-			void compressExited();
+			void compressExited(int exitCode, QProcess::ExitStatus status);
 			void compressStdoutReady();
 
 		public:
 			ImgArchiver(const ImgDirSink &sink);
 			virtual ~ImgArchiver();
 			
-			virtual void create(const QString &destname, ArchiveType type, QValueList<int> pages);
+			virtual void create(const QString &destname, ArchiveType type, QList<int> pages);
 	};
 }
 
