@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -10,15 +10,17 @@
  * WITHOUT ANY WARRANTY. See GPL for more details.
  */
 
-#include "imlibimage.h"
 #include "imgdirsink.h"
+#include "imgcache.h"
 #include "cbsettings.h"
 #include "thumbnail.h"
-#include <qstringlist.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qtextstream.h>
+#include <QImage>
+#include <QStringList>
+#include <QDir>
+#include <QFile>
+#include <QFileInfo>
+#include <QTextStream>
+#include <iostream>
 
 using namespace QComicBook;
 
@@ -28,19 +30,26 @@ const int ImgDirSink::MAX_TEXTFILE_SIZE = 65535;
                         
 const QString ImgDirSink::imgext[] = {".jpg", ".jpeg", ".png", ".gif", ".xpm", ".bmp", NULL};
 
-ImgDirSink::ImgDirSink(bool dirs): QObject(), dirpath(QString::null), dirsfirst(dirs)
+ImgDirSink::ImgDirSink(bool dirs, int cacheSize): QObject(), dirpath(QString::null), DirReader(QDir::DirsLast|QDir::Name|QDir::IgnoreCase, 6)
 {
+	cache = new ImgCache(cacheSize);
+	imgloader.setSink(this);
         thloader.setSink(this);
 }
 
-ImgDirSink::ImgDirSink(const QString &path, bool dirs): QObject(), dirpath(QString::null), dirsfirst(dirs)
+ImgDirSink::ImgDirSink(const QString &path, bool dirs, int cacheSize): QObject(), dirpath(QString::null), DirReader(QDir::DirsLast|QDir::Name|QDir::IgnoreCase, 6)
 {
+	cache = new ImgCache(cacheSize);
+	imgloader.setSink(this);
         thloader.setSink(this);
         open(path);
 }
 
-ImgDirSink::ImgDirSink(const ImgDirSink &sink): QObject()
+ImgDirSink::ImgDirSink(const ImgDirSink &sink, int cacheSize): QObject(), DirReader(QDir::DirsLast|QDir::Name|QDir::IgnoreCase, 6)
 {
+	cache = new ImgCache(cacheSize);
+
+	imgloader.setSink(this);
         thloader.setSink(this);
 
 	dirpath = sink.dirpath;
@@ -50,12 +59,17 @@ ImgDirSink::ImgDirSink(const ImgDirSink &sink): QObject()
 	otherfiles = sink.otherfiles;
 	dirs = sink.dirs;
 	timestamps = sink.timestamps;
-	dirsfirst = sink.dirsfirst;
 }
 
 ImgDirSink::~ImgDirSink()
 {
         close();
+	delete cache;
+}
+
+void ImgDirSink::setCacheSize(int cacheSize, bool autoAdjust)
+{
+	cache->setSize(cacheSize, autoAdjust);
 }
 
 void ImgDirSink::setComicBookName(const QString &name)
@@ -83,34 +97,22 @@ QString ImgDirSink::memPrefix(int &s)
         return mempfix;
 }
 
-void ImgDirSink::recurseDir(const QString &s)
+bool ImgDirSink::fileHandler(const QFileInfo &finfo)
 {
-        QDir dir(s);
-        dir.setSorting(QDir::DirsFirst|QDir::Name);
-        dir.setMatchAllDirs(true);
-        const QStringList files = dir.entryList();
-        for (QStringList::const_iterator it = files.begin(); it!=files.end(); ++it)
-        {
-                if (*it == "." || *it == "..")
-                        continue;
-
-                QFileInfo finf(dir.absFilePath(*it, false));
-                if (finf.isFile())
-                {
-			if (knownImageExtension(*it))
-                                imgfiles.append(finf.absFilePath());
-                        else if ((*it).endsWith(".nfo", false) || (*it) == "file_id.diz")
-                                txtfiles.append(finf.absFilePath());
-                        else
-                                otherfiles.append(finf.absFilePath());
-			timestamps.insert(finf.absFilePath(), FileStatus(finf.lastModified()));
-                }
-                else if (finf.isDir() && (finf.absFilePath()!=s))
-                {
-                        dirs.append(finf.absFilePath());
-                        recurseDir(finf.absFilePath());
-                }
-        }
+	const QString fname = finfo.fileName();
+	if (knownImageExtension(fname))
+	{
+		imgfiles.append(finfo.absoluteFilePath());
+		timestamps.insert(finfo.absoluteFilePath(), FileStatus(finfo.lastModified()));
+		return true;
+	}
+	if (fname.endsWith(".nfo", Qt::CaseInsensitive) || fname == "file_id.diz")
+	{
+		txtfiles.append(finfo.absoluteFilePath());
+		return true;
+	}
+	otherfiles.append(finfo.absoluteFilePath());
+	return false;
 }
 
 int ImgDirSink::open(const QString &path)
@@ -127,7 +129,7 @@ int ImgDirSink::open(const QString &path)
                         if (info.isReadable() && info.isExecutable())
                         {
                                 dirpath = path;
-                                recurseDir(path);
+				visit(path);
                                 status = (numOfImages() > 0) ? 0 : SINKERR_EMPTY;
                         }
                         else
@@ -137,12 +139,7 @@ int ImgDirSink::open(const QString &path)
         }
         setComicBookName(path);
         if (status == 0)
-        {
                 emit progress(1, 1);
-                emit sinkReady(path);
-        }
-        else
-                emit sinkError(status);
         return status;
 }
 
@@ -188,7 +185,7 @@ QStringList ImgDirSink::getDescription() const
 		{
 			QFileInfo finfo(*it);
 			QFile f(*it);
-			if (f.open(IO_ReadOnly) && (f.size() < MAX_TEXTFILE_SIZE))
+			if (f.open(QIODevice::ReadOnly) && (f.size() < MAX_TEXTFILE_SIZE))
 			{
 				QString cont;
 				QTextStream str(&f);
@@ -203,49 +200,63 @@ QStringList ImgDirSink::getDescription() const
         return desc;
 }
 
-ImlibImage* ImgDirSink::getImage(unsigned int num, int &result)
+QImage ImgDirSink::getImage(unsigned int num, int &result)
 {
         result = SINKERR_LOADERROR;
 
         listmtx.lock();
         const int imgcnt = imgfiles.count();
-        if (num < imgcnt)
+	QImage im;
+
+	if (cache->get(num, im))
+	{
+		listmtx.unlock();
+		result = 0;
+		std::cout << "from cache: " << num << std::endl;
+	}
+	else if (num < imgcnt)
 	{
 		const QString fname = imgfiles[num];
 		listmtx.unlock();
 
-		ImlibImage *im = new ImlibImage();
-		if (!im->load(fname))
-		{
-			delete im;
-			im = NULL;
-		}
-		result = 0;
+		if (!im.load(fname))
+			result = 1;
+		else
+			result = 0;
 
 		/*const QFileInfo finf(fname);
 
-		if (rimg.load(fname))
+		f (rimg.load(fname))
 		{
 			result = 0;
 			if (timestamps[fname] != finf.lastModified())
 				timestamps[fname].set(finf.lastModified(), true);
 		}*/
-		return im;
+
+		cache->insertImage(num, im);
+		std::cout << "to cache: " << num << std::endl;
 	}
         else
+	{
                 listmtx.unlock();
-	return NULL;
+		result = 0;
+	}
+
+	return im;
 }
 
 void ImgDirSink::preload(unsigned int num)
 {
-	QString name;
 	listmtx.lock();
-	if (num < imgfiles.count())
-		name = imgfiles[num];
-	listmtx.unlock();
-	if (!name.isEmpty())
-		imgloader.request(name);
+	if (num >= imgfiles.count())
+	{
+		listmtx.unlock();
+	}
+	else
+	{
+		listmtx.unlock();
+		imgloader.request(num);
+	}
 }
 
 Thumbnail* ImgDirSink::getThumbnail(int num, bool thumbcache)
@@ -348,7 +359,7 @@ bool ImgDirSink::hasModifiedFiles() const
 	for (QMap<QString, FileStatus>::ConstIterator it = timestamps.begin(); it != timestamps.end(); ++it)
 	{
 		QFileInfo finf(it.key());
-		if (it.data().isModified() || it.data() != finf.lastModified())
+		if ((*it).isModified() || *it != finf.lastModified())
 			return true;
 	}
 	return false;
@@ -380,7 +391,7 @@ void ImgDirSink::removeThumbnails(int days)
         const QStringList files = dir.entryList();
         for (QStringList::const_iterator it = files.begin(); it!=files.end(); it++)
         {
-                QFileInfo finfo(dir.absFilePath(*it));
+                QFileInfo finfo(dir.absoluteFilePath(*it));
                 if (finfo.lastModified().daysTo(currdate) > days)
                         dir.remove(*it);
         }
@@ -393,17 +404,28 @@ ThumbnailLoaderThread& ImgDirSink::thumbnailLoader()
 
 bool ImgDirSink::knownImageExtension(const QString &path)
 {
-	for (int i=0; imgext[i]; i++)
-		if (path.endsWith(imgext[i], false))
+	for (int i=0; imgext[i] != NULL; i++)
+		if (path.endsWith(imgext[i], Qt::CaseInsensitive))
 			return true;
 	return false;
 }
 
 QString ImgDirSink::getKnownImageExtension(const QString &path)
 {
-	for (int i=0; imgext[i]; i++)
-		if (path.endsWith(imgext[i], false))
+	for (int i=0; imgext[i] != NULL; i++)
+		if (path.endsWith(imgext[i], Qt::CaseInsensitive))
 			return imgext[i];
 	return false;
 }
 
+QStringList ImgDirSink::getKnownImageExtensionsList()
+{
+	QStringList list;
+	for (int i=0; imgext[i] != NULL; i++)
+	{
+		QString p = "*" + imgext[i];
+		list << p;
+	}
+	return list;
+}
+
