@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -10,10 +10,9 @@
  * WITHOUT ANY WARRANTY. See GPL for more details.
  */
 
-#include <qpushbutton.h>
-#include <qhbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QPushButton>
+#include <QLabel>
+#include <QHBoxLayout>
 #include "jumptopagewin.h"
 #include "pagenumberedit.h"
 
@@ -21,24 +20,23 @@ using namespace QComicBook;
 
 JumpToPageWindow::JumpToPageWindow(QWidget *parent, int value, int max): QDialog(parent)
 {
-	setCaption(tr("Jump to page..."));
+	setWindowTitle(tr("Jump to page..."));
 	setModal(true);
 	
-	QHBoxLayout *lay = new QHBoxLayout(this, 5, 5);
+	QHBoxLayout *lay = new QHBoxLayout(this);
 	
-	QHBox *box = new QHBox(this);
-	lay->addWidget(box);
-	box->setSpacing(5);
-	new QLabel(tr("Page number"), box);
-	pedit = new PageNumberEdit(box, value, max);
-	new QLabel(QString("/") + QString::number(max), box);
-	QPushButton *b_ok = new QPushButton(tr("Jump"), box);
+	lay->addWidget(new QLabel(tr("Page number"), this));
+	pedit = new PageNumberEdit(this, value, max);
+	lay->addWidget(pedit);
+	lay->addWidget(new QLabel(QString("/") + QString::number(max), this));
+	QPushButton *b_ok = new QPushButton(tr("Jump"), this);
+	lay->addWidget(b_ok);
 	connect(b_ok, SIGNAL(clicked()), this, SLOT(jumpPressed()));
 	connect(b_ok, SIGNAL(clicked()), this, SLOT(close()));
 	b_ok->setDefault(true);
 	connect(pedit, SIGNAL(pageSelected(int)), this, SIGNAL(pageSelected(int)));
-	pedit->setFocusPolicy(QWidget::StrongFocus);
 	pedit->setFocus();
+	pedit->setFocusPolicy(Qt::StrongFocus);
 	pedit->deselect();
 	setFixedWidth(280);
 }
