@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -14,7 +14,7 @@
 
 using namespace QComicBook;
 
-ListViewThumbnail::ListViewThumbnail(QListView *parent, QListViewItem *after, int page): QCheckListItem(parent, after, QString::number(page+1), QCheckListItem::CheckBox), ThumbnailItem(page)
+ListViewThumbnail::ListViewThumbnail(QListWidget *parent, QListWidgetItem *after, int page) : ThumbnailItem(page) //: QListWidgetItem(parent, after, QString::number(page+1), QCheckListItem::CheckBox), ThumbnailItem(page)
 {
 }
 
