@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -15,15 +15,17 @@
 
 /*! \file thumbnaillistitem.h */
 
-#include <qlistview.h>
+#include <QListWidgetItem>
 #include "thumbnailitem.h"
 
+class QListWidget;
+
 namespace QComicBook
 {
-	class ListViewThumbnail: public QCheckListItem, public ThumbnailItem
+	class ListViewThumbnail: public QListWidgetItem, public ThumbnailItem
 	{
 		public:
-			ListViewThumbnail(QListView *parent, QListViewItem *after, int page);
+			ListViewThumbnail(QListWidget *parent, QListWidgetItem *after, int page);
 			virtual ~ListViewThumbnail();
 	};
 }
