@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -10,10 +10,10 @@
  * WITHOUT ANY WARRANTY. See GPL for more details.
  */
 
-#include <qapplication.h>
-#include <qmessagebox.h>
-#include <qsplashscreen.h>
-#include <qtimer.h>
+#include <QApplication>
+#include <QMessageBox>
+#include <QSplashScreen>
+#include <QTimer>
 #include "imgarchivesink.h"
 #include "icons.h"
 #include "comicmain.h"
@@ -54,7 +54,7 @@ int main(int argc, char *argv[])
 	ImgArchiveSink::autoconfArchivers();
 		
 	ComicMainWindow *win = new ComicMainWindow(NULL);
-	app.setMainWidget(win);
+	//app.setMainWidget(win);
 	win->show();
 
 	//
@@ -68,7 +68,8 @@ int main(int argc, char *argv[])
 	{
 		QTimer *timer = new QTimer(win);
 		QObject::connect(timer, SIGNAL(timeout()), splash, SLOT(close()));
-		timer->start(2000, true);
+		timer->setSingleShot(true);
+		timer->start(2000);
 		//splash->finish(win);
 	}
 
