@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -15,11 +15,11 @@
 
 /*! \file suparchwin.h */
 
-#include <qdialog.h>
+#include <QDialog>
 
 namespace QComicBook
 {
-	class SupportedArchivesWindow: public QWidget
+	class SupportedArchivesWindow: public QDialog
 	{
 		Q_OBJECT
 
