@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -43,7 +43,7 @@ const QImage& Thumbnail::image() const
 
 void Thumbnail::touch(const QString &fname)
 {
-	utime(fname.local8Bit(), NULL);
+	utime(fname.toLocal8Bit(), NULL);
 }
 
 bool Thumbnail::tryLoad(const QString &fname)
@@ -65,7 +65,7 @@ bool Thumbnail::save(const QString &fname)
 void Thumbnail::setImage(const QImage &i)
 {
 	if (i.width() > thwidth || i.height() > thheight)
-		img = i.smoothScale(thwidth, thheight, QImage::ScaleMin);
+		img = i.scaled(thwidth, thheight, Qt::KeepAspectRatio);
 	else
 		img = i.copy();
 }
