@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -15,7 +15,7 @@
 
 /*! \file thumbnailevent.h */
 
-#include <qevent.h>
+#include <QEvent>
 
 #define ThumbnailReady 65111
 
@@ -24,7 +24,7 @@ namespace QComicBook
 
 	class Thumbnail;
 
-	class ThumbnailEvent: public QCustomEvent
+	class ThumbnailEvent: public QEvent
 	{
 		private:
 			Thumbnail *thumbnail;
