@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -14,7 +14,7 @@
 #include "imgdirsink.h"
 #include "thumbnail.h"
 #include "thumbnailevent.h"
-#include <qapplication.h>
+#include <QApplication>
  
 using namespace QComicBook;
 
