@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -13,36 +13,36 @@
 #ifndef __THUMBNAILSVIEW_H
 #define __THUMBNAILSVIEW_H
 
-#include <qiconview.h>
-#include <qptrvector.h>
+#include <QListWidget>
+#include <QVector>
 #include <iconviewthumbnail.h>
 
 class QPixmap;
-class QIconViewItem;
-class QPopupMenu;
+class QMenu;
+class QListWidgetItem;
  
 namespace QComicBook
 {
 	class Thumbnail;
 
-	class ThumbnailsView: public QIconView
+	class ThumbnailsView: public QListWidget
 	{
 		Q_OBJECT
 
 		private:
 			int numpages;
 			QPixmap *emptypage;
-			QPtrVector<IconViewThumbnail> icons;
-			QPopupMenu *menu;
-			QIconViewItem *selected;
+			QVector<IconViewThumbnail *> icons;
+			QMenu *menu;
+			QListWidgetItem *selected;
 
 		signals:
 			void requestedPage(int n, bool force);
 
 		protected slots:
-			void onDoubleClick(QIconViewItem *item);
-			void showContextMenu(QIconViewItem *item, const QPoint &p);
+			void onDoubleClick(QListWidgetItem *item);
 			void goToPageAction();
+			virtual void contextMenuEvent(QContextMenuEvent *e);
 
 		public:
 			ThumbnailsView(QWidget *parent);
@@ -51,7 +51,7 @@ namespace QComicBook
 
 		public slots:
 			void setPages(int pages);
-			void setPage(int n, const QImage &img);
+			void setPage(int n, const QPixmap &img);
 			void setPage(const Thumbnail &t);
 			void clear();
 			void scrollToPage(int n);
