@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
+ * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -18,23 +18,23 @@
 
 using namespace QComicBook;
 
-ThumbnailsWindow::ThumbnailsWindow(Place p, QWidget *parent): QDockWindow(p, parent)
+ThumbnailsWindow::ThumbnailsWindow(QWidget *parent): QDockWidget(parent)
 {
-	setCaption(tr("Thumbnails"));
-	setResizeEnabled(true);
-	setCloseMode(QDockWindow::Always);
+	setWindowTitle(tr("Thumbnails"));
+	//setResizeEnabled(true);
+	//setCloseMode(QDockWindow::Always);
 
 	tview = new ThumbnailsView(this);
 	setWidget(tview);
 	connect(tview, SIGNAL(requestedPage(int, bool)), this, SIGNAL(requestedPage(int, bool)));
-	connect(this, SIGNAL(orientationChanged(Orientation)), this, SLOT(onOrientationChanged(Orientation)));
+	//connect(this, SIGNAL(orientationChanged(Orientation)), this, SLOT(onOrientationChanged(Orientation)));
 }
 
 ThumbnailsWindow::~ThumbnailsWindow()
 {
 }
 
-void ThumbnailsWindow::customEvent(QCustomEvent *e)
+void ThumbnailsWindow::customEvent(QEvent *e)
 {
 	if (e->type() == ThumbnailReady)
 	{
@@ -42,13 +42,21 @@ void ThumbnailsWindow::customEvent(QCustomEvent *e)
 		tview->setPage(*evt->getThumbnail());
 	}
 	else
-		QDockWindow::customEvent(e);
+	{
+		QDockWidget::customEvent(e);
+	}
 }
 
-void ThumbnailsWindow::onOrientationChanged(Orientation o)
+void ThumbnailsWindow::showEvent(QShowEvent *e)
+{
+	QDockWidget::showEvent(e);
+	emit shown();
+}
+
+/*void ThumbnailsWindow::onOrientationChanged(Orientation o)
 {
 	tview->setArrangement(o == Qt::Horizontal ? QIconView::TopToBottom : QIconView::LeftToRight);
-}
+}*/
 
 ThumbnailsView* ThumbnailsWindow::view() const
 {
